import { l as lib } from './generated-index.js';
import { p } from './hsl2hsv.js';

console.log(p);
var main = new Map(Object.entries(lib));

export { main as default };
